"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startFullSnapshots = startFullSnapshots;
const browser_rum_core_1 = require("@datadog/browser-rum-core");
const browser_core_1 = require("@datadog/browser-core");
const types_1 = require("../../types");
const serialization_1 = require("./serialization");
const viewports_1 = require("./viewports");
function startFullSnapshots(elementsScrollPositions, shadowRootsController, lifeCycle, configuration, flushMutations, fullSnapshotCallback) {
    const takeFullSnapshot = (timestamp = (0, browser_core_1.timeStampNow)(), serializationContext = {
        status: 0 /* SerializationContextStatus.INITIAL_FULL_SNAPSHOT */,
        elementsScrollPositions,
        shadowRootsController,
    }) => {
        const { width, height } = (0, browser_rum_core_1.getViewportDimension)();
        const records = [
            {
                data: {
                    height,
                    href: window.location.href,
                    width,
                },
                type: types_1.RecordType.Meta,
                timestamp,
            },
            {
                data: {
                    has_focus: document.hasFocus(),
                },
                type: types_1.RecordType.Focus,
                timestamp,
            },
            {
                data: {
                    node: (0, serialization_1.serializeDocument)(document, configuration, serializationContext),
                    initialOffset: {
                        left: (0, browser_rum_core_1.getScrollX)(),
                        top: (0, browser_rum_core_1.getScrollY)(),
                    },
                },
                type: types_1.RecordType.FullSnapshot,
                timestamp,
            },
        ];
        if (window.visualViewport) {
            records.push({
                data: (0, viewports_1.getVisualViewport)(window.visualViewport),
                type: types_1.RecordType.VisualViewport,
                timestamp,
            });
        }
        return records;
    };
    fullSnapshotCallback(takeFullSnapshot());
    const { unsubscribe } = lifeCycle.subscribe(2 /* LifeCycleEventType.VIEW_CREATED */, (view) => {
        flushMutations();
        fullSnapshotCallback(takeFullSnapshot(view.startClocks.timeStamp, {
            shadowRootsController,
            status: 1 /* SerializationContextStatus.SUBSEQUENT_FULL_SNAPSHOT */,
            elementsScrollPositions,
        }));
    });
    return {
        stop: unsubscribe,
    };
}
//# sourceMappingURL=startFullSnapshots.js.map